/***************************************************************************
                          cdemodulator.cpp  -  description
                             -------------------
    begin                : Sat Jun 2 2001
    copyright            : (C) 2001 by Volker Schroer
    email                : dl1ksv@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include "cdemodulator.h"

CDemodulator::CDemodulator()
{
UseAfc = true;
Squelch = true;
Threshold= 50;
}

CDemodulator::~CDemodulator()
{
}

void CDemodulator::setAfc(bool afc) { UseAfc=afc; }

void CDemodulator::setRxFrequency(double freq)
{
RxFrequency = freq;
}

double CDemodulator::getRxFrequency(void)
{
return RxFrequency;
}

void CDemodulator::setThreshold(int value)
{
Threshold= value;
}

void CDemodulator::setSquelch(bool OnOff)
{
Squelch=OnOff;
}

bool CDemodulator::getAFC()
{
return UseAfc;
}
bool CDemodulator::getSquelchState()
{
return Squelch;
}
std::complex<float> * CDemodulator::getPhasePointer()
{
return 0;
}
int CDemodulator::getThreshold()
{
return Threshold;
}

